updateDecryptionKey method
Set the decryption key before calling play or playWithResourceLoad.
Implementation
Future<void> updateDecryptionKey(String decryptionKey) =>
_invoke('updateDecryptionKey', {'decryptionKey': decryptionKey});
Set the decryption key before calling play or playWithResourceLoad.
Future<void> updateDecryptionKey(String decryptionKey) =>
_invoke('updateDecryptionKey', {'decryptionKey': decryptionKey});