PlayerView class

A widget that renders the native iOS / Android video player.

mode 决定本实例的播放器模式,默认 PlayerMode.normal。传入 PlayerMode.shortDrama 时:

  • Flutter 层不再注册 EagerGestureRecognizer,垂直/水平拖动让给外层 (例如上下滑切集的 PageView
  • widget 在 platform view 创建完成后自动调用 PlayerController.setPlayerMode,通知原生同步禁用内部 pan

mode 构造期不可变。运行时切换需用不同 ValueKey 强制重建。

Inheritance

Constructors

PlayerView({required PlayerController controller, PlayerMode mode = PlayerMode.normal, PlayerFitMode? fitMode, Key? key})
const

Properties

controller PlayerController
final
fitMode PlayerFitMode?
初始画面填充模式。null 使用原生默认(contain)。运行时切换请调用 PlayerController.setFitMode,不要直接修改该 widget 参数。
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mode PlayerMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<PlayerView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited