onFullscreenTap property
Called when the fullscreen button is tapped. If null, the button still appears but calls PlayerController.enterFullscreen / PlayerController.exitFullscreen automatically.
Implementation
final VoidCallback? onFullscreenTap;
Called when the fullscreen button is tapped. If null, the button still appears but calls PlayerController.enterFullscreen / PlayerController.exitFullscreen automatically.
final VoidCallback? onFullscreenTap;