MoheVVC class
火龙 VVC (H.266) 全屏播放。
对一个 VVC HLS m3u8 URL(如腾讯视频 tc.qq.com 的 f307510 流),绕开 AVPlayer / VLCKit / FFmpegDecryptPlayer 三条传统引擎,直接用独立 ffmpeg 8.x VVC native decoder + UIImageView 渲染 + AVAudioEngine。当前仅 iOS 真机实现。
Constructors
- MoheVVC()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
events
→ Stream<
PlayerEvent> -
火龙播放事件流。当前事件:
no setter
Static Methods
-
playFullScreen(
String url) → Future< void> - 全屏播放 VVC HLS m3u8 URL。在 keyWindow 上盖一层覆盖 View 显示画面, 顶部有"× 关闭"按钮可手动关闭。
-
stopFullScreen(
) → Future< void> - 关闭当前火龙 VVC 全屏播放。幂等。