PlayerFitMode enum
画面填充模式。
透传到原生的 fit-mode creationParam,创建时生效;运行时切换通过
PlayerController.setFitMode 动态更新,无需重建 widget。
Values
- contain → const PlayerFitMode
- cover → const PlayerFitMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PlayerFitMode> - A constant List of the values in this enum, in order of their declaration.