PreloadRequest class
单个视频预加载请求。对齐 iOS {@code ILookPreloadTask}。
priority 数值越大越先下载;与 inflight 最低优先级差距 > 2 时触发抢占。
Constructors
- PreloadRequest({required String url, required String decryptionKey, int priority = 0})
-
const
Properties
- decryptionKey → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited