MobileOverlay class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- MobileOverlay
Constructors
-
MobileOverlay({Key? key, required PlayerController controller, required PlayerUIState state, bool isFullscreen = false, String? videoTitle, VoidCallback? onBack, VoidCallback? onToggleFullscreen, VoidCallback? onNextEpisode, VoidCallback? onSelectSpeed, VoidCallback? onSelectQuality, VoidCallback? onSelectEpisode, ValueChanged<
String> ? onSendBarrage, VoidCallback? onToggleBarrage}) -
const
Properties
- controller → PlayerController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullscreen → bool
-
false = portrait, true = landscape/fullscreen
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onBack → VoidCallback?
-
Back button callback (always visible in portrait; in landscape top bar)
final
- onNextEpisode → VoidCallback?
-
Landscape: next episode button
final
- onSelectEpisode → VoidCallback?
-
Landscape: episode selection
final
- onSelectQuality → VoidCallback?
-
Landscape: quality selection
final
- onSelectSpeed → VoidCallback?
-
Landscape: speed selection
final
-
onSendBarrage
→ ValueChanged<
String> ? -
Landscape: send barrage text
final
- onToggleBarrage → VoidCallback?
-
Toggle barrage visibility
final
- onToggleFullscreen → VoidCallback?
-
Toggle fullscreen (portrait bottom bar button)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → PlayerUIState
-
final
- videoTitle → String?
-
Title shown in landscape top bar
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< MobileOverlay> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited