VideoProgressBar class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- VideoProgressBar
Constructors
-
VideoProgressBar({Key? key, required double played, double buffered = 0.0, Duration? currentTime, Duration? totalTime, double trackHeight = 1.5, Color playedColor = const Color(0xFF01BEBE), Color bufferedColor = const Color(0x26FFFFFF), Color unplayedColor = const Color(0x4DFFFFFF), List<
double> markerPoints = const [], void onSeekStart(double progress)?, void onSeekUpdate(double progress)?, void onSeekEnd(double progress)?}) -
const
Properties
- buffered → double
-
0.0 – 1.0: fraction buffered.
final
- bufferedColor → Color
-
Colour of the buffered portion. Default: white 15%.
final
- currentTime → Duration?
-
Current playback time used to show the seek label.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
markerPoints
→ List<
double> -
List of fractional positions (0.0 – 1.0) for white dot markers.
final
- onSeekEnd → void Function(double progress)?
-
final
- onSeekStart → void Function(double progress)?
-
final
- onSeekUpdate → void Function(double progress)?
-
final
- played → double
-
0.0 – 1.0: fraction played.
final
- playedColor → Color
-
Colour of the played portion. Default: #01BEBE.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalTime → Duration?
-
Total duration used to compute absolute seek time from fraction.
final
- trackHeight → double
-
Idle track height (px). Native: 1.5 portrait, 2.0 landscape.
final
- unplayedColor → Color
-
Colour of the unplayed portion. Default: white 30%.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< VideoProgressBar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited